pub struct CausalMultiVectorWitness;Trait Implementations
Sourceimpl Applicative<CausalMultiVectorWitness> for CausalMultiVectorWitness
impl Applicative<CausalMultiVectorWitness> for CausalMultiVectorWitness
Sourcefn pure<T>(value: T) -> CausalMultiVector<T>
fn pure<T>(value: T) -> CausalMultiVector<T>
Lifts a pure value into the minimal applicative context
F::Type<T>. Read moreSourcefn apply<A, B, Func>(
f_ab: CausalMultiVector<Func>,
f_a: CausalMultiVector<A>,
) -> CausalMultiVector<B>
fn apply<A, B, Func>( f_ab: CausalMultiVector<Func>, f_a: CausalMultiVector<A>, ) -> CausalMultiVector<B>
Sourceimpl BoundedAdjunction<CausalMultiVectorWitness, CausalMultiVectorWitness, Metric> for CausalMultiVectorWitness
impl BoundedAdjunction<CausalMultiVectorWitness, CausalMultiVectorWitness, Metric> for CausalMultiVectorWitness
Sourcefn left_adjunct<A, B, F>(ctx: &Metric, a: A, f: F) -> CausalMultiVector<B>
fn left_adjunct<A, B, F>(ctx: &Metric, a: A, f: F) -> CausalMultiVector<B>
The Left Adjunct: $(L(A) \to B) \to (A \to R(B))$
Transforms a function on the “Left” structure to a function on the “Right” structure,
using the provided context.
Sourcefn right_adjunct<A, B, F>(ctx: &Metric, la: CausalMultiVector<A>, f: F) -> B
fn right_adjunct<A, B, F>(ctx: &Metric, la: CausalMultiVector<A>, f: F) -> B
The Right Adjunct: $(A \to R(B)) \to (L(A) \to B)$
Transforms a function on the “Right” structure to a function on the “Left” structure,
using the provided context.
Sourcefn unit<A>(ctx: &Metric, a: A) -> CausalMultiVector<CausalMultiVector<A>>
fn unit<A>(ctx: &Metric, a: A) -> CausalMultiVector<CausalMultiVector<A>>
The Unit of the Adjunction: $A \to R(L(A))$
Embeds a value into the Right-Left context, using the provided context.
Sourcefn counit<B>(_ctx: &Metric, lrb: CausalMultiVector<CausalMultiVector<B>>) -> B
fn counit<B>(_ctx: &Metric, lrb: CausalMultiVector<CausalMultiVector<B>>) -> B
The Counit of the Adjunction: $L(R(B)) \to B$
Collapses the Left-Right context back to a value, using the provided context.
Sourceimpl BoundedComonad<CausalMultiVectorWitness> for CausalMultiVectorWitness
impl BoundedComonad<CausalMultiVectorWitness> for CausalMultiVectorWitness
fn extract<A>(fa: &CausalMultiVector<A>) -> Awhere
A: Clone,
fn extend<A, B, Func>( fa: &CausalMultiVector<A>, f: Func, ) -> CausalMultiVector<B>
Sourceimpl Functor<CausalMultiVectorWitness> for CausalMultiVectorWitness
impl Functor<CausalMultiVectorWitness> for CausalMultiVectorWitness
Sourcefn fmap<A, B, F>(fa: CausalMultiVector<A>, f: F) -> CausalMultiVector<B>where
F: FnMut(A) -> B,
fn fmap<A, B, F>(fa: CausalMultiVector<A>, f: F) -> CausalMultiVector<B>where
F: FnMut(A) -> B,
Sourceimpl HKT for CausalMultiVectorWitness
impl HKT for CausalMultiVectorWitness
Sourcetype Type<A> = CausalMultiVector<A>
type Type<A> = CausalMultiVector<A>
The Generic Associated Type (GAT) that represents the type constructor.
The
<T> is the “hole” in the type constructor (e.g., Option<T>).Sourceimpl Monad<CausalMultiVectorWitness> for CausalMultiVectorWitness
impl Monad<CausalMultiVectorWitness> for CausalMultiVectorWitness
Sourcefn bind<A, B, Func>(m_a: CausalMultiVector<A>, f: Func) -> CausalMultiVector<B>where
Func: FnMut(A) -> CausalMultiVector<B>,
fn bind<A, B, Func>(m_a: CausalMultiVector<A>, f: Func) -> CausalMultiVector<B>where
Func: FnMut(A) -> CausalMultiVector<B>,
Chains a computation from an effectful value, flattening the result.
This is the core sequencing operation of a Monad. Read more