pub struct HilbertState { /* private fields */ }Expand description
A strong type representing a Quantum State Vector (Ket) |ψ>.
This represents a Minimal Left Ideal of the algebra Cl(10) (or others), acting as the Hilbert Space.
Invariants
- The coefficients are always
Complex<f64>. - The Metric is fixed at construction time (preventing mixed-algebra operations).
Implementations
Sourceimpl HilbertState
impl HilbertState
Sourcepub fn new_spin10(
data: Vec<Complex<f64>>,
) -> Result<Self, CausalMultiVectorError>
pub fn new_spin10( data: Vec<Complex<f64>>, ) -> Result<Self, CausalMultiVectorError>
Creates a new Hilbert State for the Grand Unified Algebra (Spin(10)). This enforces the metric Cl(10) (NonEuclidean, 10D).
Sourcepub fn new(
data: Vec<Complex<f64>>,
metric: Metric,
) -> Result<Self, CausalMultiVectorError>
pub fn new( data: Vec<Complex<f64>>, metric: Metric, ) -> Result<Self, CausalMultiVectorError>
Generic constructor for other quantum systems (e.g. Qubits / Cl(2)).
pub fn new_unchecked(data: Vec<Complex<f64>>, metric: Metric) -> Self
pub fn from(mv: CausalMultiVector<Complex<f64>>) -> Self
Sourcepub fn into_inner(self) -> CausalMultiVector<Complex<f64>>
pub fn into_inner(self) -> CausalMultiVector<Complex<f64>>
Unwraps the state to access the underlying algebraic object. Useful when you need to perform raw geometric operations.
Sourcepub fn as_inner(&self) -> &CausalMultiVector<Complex<f64>>
pub fn as_inner(&self) -> &CausalMultiVector<Complex<f64>>
Borrows the underlying algebraic object.
pub fn mv(&self) -> &CausalMultiVector<Complex<f64>>